aboutsummaryrefslogtreecommitdiff
path: root/tests/testthat/test_saemix_parent.R
diff options
context:
space:
mode:
Diffstat (limited to 'tests/testthat/test_saemix_parent.R')
-rw-r--r--tests/testthat/test_saemix_parent.R6
1 files changed, 4 insertions, 2 deletions
diff --git a/tests/testthat/test_saemix_parent.R b/tests/testthat/test_saemix_parent.R
index 2f05c175..8beceba9 100644
--- a/tests/testthat/test_saemix_parent.R
+++ b/tests/testthat/test_saemix_parent.R
@@ -1,3 +1,5 @@
+context("saemix parent models")
+
test_that("Parent fits using saemix are correctly implemented", {
expect_error(saem(fits), "Only row objects")
@@ -63,9 +65,9 @@ test_that("Parent fits using saemix are correctly implemented", {
expect_true(all(rel_diff_mmkin[c("parent_0", "k1")] < 0.20))
expect_true(all(rel_diff_mmkin_tested[c("parent_0", "k1", "k2")] < 0.20))
# We get < 15% deviations with transformations made in mkin
rel_diff_1 <- (s_dfop_s1$confint_back[, "est."] - dfop_pop) / dfop_pop
- expect_true(all(rel_diff_1 < 0.15))
+ expect_true(all(rel_diff_1 < 0.20))
# We get < 20% deviations with transformations made in saemix
rel_diff_2 <- (s_dfop_s2$confint_back[, "est."] - dfop_pop) / dfop_pop
@@ -63,9 +65,9 @@ test_that("Parent fits using saemix are correctly implemented", {
expect_true(all(rel_diff_mmkin[c("parent_0", "k1")] < 0.20))
expect_true(all(rel_diff_mmkin_tested[c("parent_0", "k1", "k2")] < 0.20))
- # We get < 15% deviations with transformations made in mkin
+ # We get < 20% deviations with transformations made in mkin
rel_diff_1 <- (s_dfop_s1$confint_back[, "est."] - dfop_pop) / dfop_pop

Contact - Imprint